DIVA_PROTOCOL_CHAINS = (137, 80001, 3, 5)

POLYGON_CHAINS = {137, 80001}

ETHEREUM_CHAINS = {1, 3, 5, 10, 420, 42161, 421613}

GNOSIS_CHAINS = {100, 10200}

FILECOIN_CHAINS = {
    3141,
}
